.. _research:

Research and contribution
=========================

Research
--------

If you are doing research using Blackbird, please cite the `StrawberryFields paper <https://quantum-journal.org/papers/q-2019-03-11-129/>`_:

	Nathan Killoran, Josh Izaac, Nicolás Quesada, Ville Bergholm, Matthew Amy, and Christian Weedbrook.
	"Strawberry Fields: A Software Platform for Photonic Quantum Computing", Quantum, 3, 129 (2019).

We are always open for collaboration; you can contact us at research@xanadu.ai.

Support
-------

- **Source Code:** https://github.com/XanaduAI/blackbird
- **Issue Tracker:** https://github.com/XanaduAI/blackbird/issues

If you are having issues, please let us know by posting the problem on our Github issue tracker.

Contribution
------------

We encourage contributions — simply fork the Blackbird repository, and then make a
`pull request <https://help.github.com/articles/about-pull-requests/>`_ containing your contribution.

We also encourage bug reports, suggestions for new features and enhancements, and even links to cool projects or applications built on Blackbird.
